@@ -205,7 +205,7 @@ static void releaseMediaPlayer(JNIEnv *env, jobject thiz)
  */
 JavaVM *myVm;
 
-static jobject eventManagerInstance = NULL;
+static jobject eventHandlerInstance = NULL;
 static jobject debugBufferInstance = NULL;
 
 static pthread_mutex_t vout_android_lock;
@@ -241,17 +241,14 @@ void jni_SetAndroidSurfaceSize(int width, int height, int sar_num, int sar_den)
 static void vlc_event_callback(const libvlc_event_t *ev, void *data)
 {
     JNIEnv *env;
-    JavaVM *myVm = data;
 
     bool isAttached = false;
 
-    if (eventManagerInstance == NULL)
+    if (eventHandlerInstance == NULL)
         return;
 
-    int status = (*myVm)->GetEnv(myVm, (void**) &env, JNI_VERSION_1_2);
-    if (status < 0) {
-        status = (*myVm)->AttachCurrentThread(myVm, &env, NULL);
-        if (status < 0)
+    if ((*myVm)->GetEnv(myVm, (void**) &env, JNI_VERSION_1_2) < 0) {
+        if ((*myVm)->AttachCurrentThread(myVm, &env, NULL) < 0)
             return;
         isAttached = true;
     }
@@ -304,18 +301,18 @@ static void vlc_event_callback(const libvlc_event_t *ev, void *data)
     }
 
     /* Get the object class */
-    jclass cls = (*env)->GetObjectClass(env, eventManagerInstance);
+    jclass cls = (*env)->GetObjectClass(env, eventHandlerInstance);
     if (!cls) {
-        LOGE("EventManager: failed to get class reference");
+        LOGE("EventHandler: failed to get class reference");
         goto end;
     }
 
     /* Find the callback ID */
     jmethodID methodID = (*env)->GetMethodID(env, cls, "callback", "(ILandroid/os/Bundle;)V");
     if (methodID) {
-        (*env)->CallVoidMethod(env, eventManagerInstance, methodID, ev->type, bundle);
+        (*env)->CallVoidMethod(env, eventHandlerInstance, methodID, ev->type, bundle);
     } else {
-        LOGE("EventManager: failed to get the callback method");
+        LOGE("EventHandler: failed to get the callback method");
     }
 
 end:
@@ -338,7 +335,7 @@ void JNI_OnUnload(JavaVM* vm, void* reserved) {
     pthread_mutex_destroy(&vout_android_lock);
 }
 
-void Java_org_videolan_vlc_LibVLC_attachSurface(JNIEnv *env, jobject thiz, jobject surf, jobject gui, jint width, jint height) {
+void Java_org_videolan_libvlc_LibVLC_attachSurface(JNIEnv *env, jobject thiz, jobject surf, jobject gui, jint width, jint height) {
     jclass clz;
     jfieldID fid;
 
@@ -360,7 +357,7 @@ void Java_org_videolan_vlc_LibVLC_attachSurface(JNIEnv *env, jobject thiz, jobje
     pthread_mutex_unlock(&vout_android_lock);
 }
 
-void Java_org_videolan_vlc_LibVLC_detachSurface(JNIEnv *env, jobject thiz) {
+void Java_org_videolan_libvlc_LibVLC_detachSurface(JNIEnv *env, jobject thiz) {
     pthread_mutex_lock(&vout_android_lock);
     vout_android_surf = NULL;
     if (vout_android_gui != NULL)
@@ -369,38 +366,17 @@ void Java_org_videolan_vlc_LibVLC_detachSurface(JNIEnv *env, jobject thiz) {
     pthread_mutex_unlock(&vout_android_lock);
 }
 
-static void debug_log(void *data, int level, const char *fmt, va_list ap)
-{
-    bool *verbose = data;
-
-    static const uint8_t priority[5] = {
-        [LIBVLC_DEBUG]   = ANDROID_LOG_DEBUG,
-        [1 /* ??? */]    = ANDROID_LOG_DEBUG,
-        [LIBVLC_NOTICE]  = ANDROID_LOG_INFO,
-        [LIBVLC_WARNING] = ANDROID_LOG_WARN,
-        [LIBVLC_ERROR]   = ANDROID_LOG_ERROR,
-    };
-
-    int prio = ANDROID_LOG_DEBUG;
-    if (level >= LIBVLC_DEBUG && level <= LIBVLC_ERROR)
-        prio = priority[level];
-
-    if (!*verbose && prio < ANDROID_LOG_ERROR)
-        return;
-
-    __android_log_vprint(prio, "VLC", fmt, ap);
-}
+// FIXME: use atomics
+static bool verbosity;
+static bool buffer_logging;
 
 static void debug_buffer_log(void *data, int level, const char *fmt, va_list ap)
 {
     bool isAttached = false;
     JNIEnv *env = NULL;
-    JavaVM *myVm = (JavaVM*)data;
 
-    int status = (*myVm)->GetEnv(myVm, (void**) &env, JNI_VERSION_1_2);
-    if (status < 0) {
-        status = (*myVm)->AttachCurrentThread(myVm, &env, NULL);
-        if (status < 0)
+    if ((*myVm)->GetEnv(myVm, (void**) &env, JNI_VERSION_1_2) < 0) {
+        if ((*myVm)->AttachCurrentThread(myVm, &env, NULL) < 0)
             return;
         isAttached = true;
     }
@@ -430,21 +406,39 @@ static void debug_buffer_log(void *data, int level, const char *fmt, va_list ap)
         (*myVm)->DetachCurrentThread(myVm);
 }
 
-static libvlc_log_subscriber_t debug_subscriber;
-static bool verbosity;
-static libvlc_log_subscriber_t debug_buffer_subscriber;
-
-void Java_org_videolan_vlc_LibVLC_changeVerbosity(JNIEnv *env, jobject thiz, jboolean verbose)
+static void debug_log(void *data, int level, const libvlc_log_t *ctx, const char *fmt, va_list ap)
 {
-    verbosity = verbose;
-    libvlc_log_unsubscribe(&debug_subscriber);
-    libvlc_log_subscribe(&debug_subscriber, debug_log, &verbosity);
+    bool *verbose = data;
+
+    static const uint8_t priority[5] = {
+        [LIBVLC_DEBUG]   = ANDROID_LOG_DEBUG,
+        [1 /* ??? */]    = ANDROID_LOG_DEBUG,
+        [LIBVLC_NOTICE]  = ANDROID_LOG_INFO,
+        [LIBVLC_WARNING] = ANDROID_LOG_WARN,
+        [LIBVLC_ERROR]   = ANDROID_LOG_ERROR,
+    };
+
+    int prio = ANDROID_LOG_DEBUG;
+    if (level >= LIBVLC_DEBUG && level <= LIBVLC_ERROR)
+        prio = priority[level];
+
+    if (buffer_logging) {
+        va_list aq;
+        va_copy(aq, ap);
+        debug_buffer_log(data, level, fmt, aq);
+        va_end(aq);
+    }
+
+    if (!*verbose && prio < ANDROID_LOG_ERROR)
+        return;
+
+    __android_log_vprint(prio, "VLC", fmt, ap);
 }
 
-void Java_org_videolan_vlc_LibVLC_startDebugBuffer(JNIEnv *env, jobject thiz)
+void Java_org_videolan_libvlc_LibVLC_startDebugBuffer(JNIEnv *env, jobject thiz)
 {
-    jclass libVLC_class = (*env)->FindClass(env, "org/videolan/vlc/LibVLC");
-    jmethodID getInstance = (*env)->GetStaticMethodID(env, libVLC_class, "getInstance", "()Lorg/videolan/vlc/LibVLC;");
+    jclass libVLC_class = (*env)->FindClass(env, "org/videolan/libvlc/LibVLC");
+    jmethodID getInstance = (*env)->GetStaticMethodID(env, libVLC_class, "getInstance", "()Lorg/videolan/libvlc/LibVLC;");
     jobject libvlcj = (*env)->CallStaticObjectMethod(env, libVLC_class, getInstance);
 
     jfieldID bufferID = (*env)->GetFieldID(env, libVLC_class, "mDebugLogBuffer", "Ljava/lang/StringBuffer;");
@@ -458,15 +452,14 @@ void Java_org_videolan_vlc_LibVLC_startDebugBuffer(JNIEnv *env, jobject thiz)
 
     (*env)->DeleteLocalRef(env, libVLC_class);
     (*env)->DeleteLocalRef(env, libvlcj);
-    libvlc_log_subscribe(&debug_buffer_subscriber, debug_buffer_log, myVm);
+    buffer_logging = true;
 }
 
-void Java_org_videolan_vlc_LibVLC_stopDebugBuffer(JNIEnv *env, jobject thiz)
+void Java_org_videolan_libvlc_LibVLC_stopDebugBuffer(JNIEnv *env, jobject thiz)
 {
-    libvlc_log_unsubscribe(&debug_buffer_subscriber);
-
-    jclass libVLC_class = (*env)->FindClass(env, "org/videolan/vlc/LibVLC");
-    jmethodID getInstance = (*env)->GetStaticMethodID(env, libVLC_class, "getInstance", "()Lorg/videolan/vlc/LibVLC;");
+    buffer_logging = false;
+    jclass libVLC_class = (*env)->FindClass(env, "org/videolan/libvlc/LibVLC");
+    jmethodID getInstance = (*env)->GetStaticMethodID(env, libVLC_class, "getInstance", "()Lorg/videolan/libvlc/LibVLC;");
     jobject libvlcj = (*env)->CallStaticObjectMethod(env, libVLC_class, getInstance);
 
     (*env)->DeleteGlobalRef(env, debugBufferInstance);
@@ -478,7 +471,7 @@ void Java_org_videolan_vlc_LibVLC_stopDebugBuffer(JNIEnv *env, jobject thiz)
     (*env)->DeleteLocalRef(env, libvlcj);
 }
 
-void Java_org_videolan_vlc_LibVLC_nativeInit(JNIEnv *env, jobject thiz, jboolean verbose)
+void Java_org_videolan_libvlc_LibVLC_nativeInit(JNIEnv *env, jobject thiz)
 {
     //only use OpenSLES if java side says we can
     jclass cls = (*env)->GetObjectClass(env, thiz);
@@ -498,8 +491,8 @@ void Java_org_videolan_vlc_LibVLC_nativeInit(JNIEnv *env, jobject thiz, jboolean
     const char *subsencodingstr = (*env)->GetStringUTFChars(env, subsencoding, 0);
     LOGD("Subtitle encoding set to \"%s\"", subsencodingstr);
 
-    verbosity = verbose;
-    libvlc_log_subscribe(&debug_subscriber, debug_log, &verbosity);
+    methodId = (*env)->GetMethodID(env, cls, "isVerboseMode", "()Z");
+    verbosity = (*env)->CallBooleanMethod(env, thiz, methodId);
 
     /* Don't add any invalid options, otherwise it causes LibVLC to crash */
     const char *argv[] = {
@@ -525,16 +518,18 @@ void Java_org_videolan_vlc_LibVLC_nativeInit(JNIEnv *env, jobject thiz, jboolean
 
     if (!instance)
     {
-        jclass exc = (*env)->FindClass(env, "org/videolan/vlc/LibVlcException");
+        jclass exc = (*env)->FindClass(env, "org/videolan/libvlc/LibVlcException");
         (*env)->ThrowNew(env, exc, "Unable to instantiate LibVLC");
     }
 
     LOGI("LibVLC initialized: %p", instance);
 
+    libvlc_log_set(instance, debug_log, &verbosity);
+
     /* Initialize media list (a.k.a. playlist/history) */
     libvlc_media_list_t* pointer = libvlc_media_list_new( instance );
     if(!pointer) {
-        jclass exc = (*env)->FindClass(env, "org/videolan/vlc/LibVlcException");
+        jclass exc = (*env)->FindClass(env, "org/videolan/libvlc/LibVlcException");
         (*env)->ThrowNew(env, exc, "Unable to create LibVLC media list");
         return;
     }
@@ -551,7 +546,7 @@ void Java_org_videolan_vlc_LibVLC_nativeInit(JNIEnv *env, jobject thiz, jboolean
     setLong(env, thiz, "mMediaListInstance", (jlong)(intptr_t)pointer);
 }
 
-jstring Java_org_videolan_vlc_LibVLC_nativeToURI(JNIEnv *env, jobject thiz, jstring path)
+jstring Java_org_videolan_libvlc_LibVLC_nativeToURI(JNIEnv *env, jobject thiz, jstring path)
 {
     jboolean isCopy;
     /* Get C string */
@@ -570,7 +565,7 @@ jstring Java_org_videolan_vlc_LibVLC_nativeToURI(JNIEnv *env, jobject thiz, jstr
     return t;
 }
 
-void Java_org_videolan_vlc_LibVLC_nativeDestroy(JNIEnv *env, jobject thiz)
+void Java_org_videolan_libvlc_LibVLC_nativeDestroy(JNIEnv *env, jobject thiz)
 {
     releaseMediaPlayer(env, thiz);
     jlong libVlcInstance = getLong(env, thiz, "mLibVlcInstance");
@@ -578,43 +573,43 @@ void Java_org_videolan_vlc_LibVLC_nativeDestroy(JNIEnv *env, jobject thiz)
         return; // Already destroyed
 
     libvlc_instance_t *instance = (libvlc_instance_t*)(intptr_t) libVlcInstance;
+    libvlc_log_unset(instance);
     libvlc_release(instance);
-    libvlc_log_unsubscribe(&debug_subscriber);
 
     setLong(env, thiz, "mLibVlcInstance", 0);
 }
 
-void Java_org_videolan_vlc_LibVLC_detachEventManager(JNIEnv *env, jobject thiz)
+void Java_org_videolan_libvlc_LibVLC_detachEventHandler(JNIEnv *env, jobject thiz)
 {
-    if (eventManagerInstance != NULL) {
-        (*env)->DeleteGlobalRef(env, eventManagerInstance);
-        eventManagerInstance = NULL;
+    if (eventHandlerInstance != NULL) {
+        (*env)->DeleteGlobalRef(env, eventHandlerInstance);
+        eventHandlerInstance = NULL;
     }
 }
 
-void Java_org_videolan_vlc_LibVLC_setEventManager(JNIEnv *env, jobject thiz, jobject eventManager)
+void Java_org_videolan_libvlc_LibVLC_setEventHandler(JNIEnv *env, jobject thiz, jobject eventHandler)
 {
-    if (eventManagerInstance != NULL) {
-        (*env)->DeleteGlobalRef(env, eventManagerInstance);
-        eventManagerInstance = NULL;
+    if (eventHandlerInstance != NULL) {
+        (*env)->DeleteGlobalRef(env, eventHandlerInstance);
+        eventHandlerInstance = NULL;
     }
 
-    jclass cls = (*env)->GetObjectClass(env, eventManager);
+    jclass cls = (*env)->GetObjectClass(env, eventHandler);
     if (!cls) {
-        LOGE("setEventManager: failed to get class reference");
+        LOGE("setEventHandler: failed to get class reference");
         return;
     }
 
     jmethodID methodID = (*env)->GetMethodID(env, cls, "callback", "(ILandroid/os/Bundle;)V");
     if (!methodID) {
-        LOGE("setEventManager: failed to get the callback method");
+        LOGE("setEventHandler: failed to get the callback method");
         return;
     }
 
-    eventManagerInstance = (*env)->NewGlobalRef(env, eventManager);
+    eventHandlerInstance = (*env)->NewGlobalRef(env, eventHandler);
 }
 
-jobjectArray Java_org_videolan_vlc_LibVLC_readMediaMeta(JNIEnv *env,
+jobjectArray Java_org_videolan_libvlc_LibVLC_readMediaMeta(JNIEnv *env,
                                                         jobject thiz, jlong instance, jstring mrl)
 {
     jobjectArray array = (*env)->NewObjectArray(env, 8,
@@ -687,7 +682,8 @@ static void create_player_and_play(JNIEnv* env, jobject thiz,
         libvlc_MediaPlayerEndReached,
         libvlc_MediaPlayerStopped,
         libvlc_MediaPlayerVout,
-        libvlc_MediaPlayerPositionChanged
+        libvlc_MediaPlayerPositionChanged,
+        libvlc_MediaPlayerEncounteredError
     };
     for(int i = 0; i < (sizeof(mp_events) / sizeof(*mp_events)); i++)
         libvlc_event_attach(ev, mp_events[i], vlc_event_callback, myVm);
@@ -702,7 +698,7 @@ static void create_player_and_play(JNIEnv* env, jobject thiz,
     libvlc_media_list_player_play_item_at_index(p_mlp, position);
 }
 
-jint Java_org_videolan_vlc_LibVLC_readMedia(JNIEnv *env, jobject thiz,
+jint Java_org_videolan_libvlc_LibVLC_readMedia(JNIEnv *env, jobject thiz,
                                             jlong instance, jstring mrl, jboolean novideo)
 {
     /* Create a new item */
@@ -733,12 +729,12 @@ jint Java_org_videolan_vlc_LibVLC_readMedia(JNIEnv *env, jobject thiz,
     return position;
 }
 
-void Java_org_videolan_vlc_LibVLC_playIndex(JNIEnv *env, jobject thiz,
+void Java_org_videolan_libvlc_LibVLC_playIndex(JNIEnv *env, jobject thiz,
                                             jlong instance, int position) {
     create_player_and_play(env, thiz, instance, position);
 }
 
-void Java_org_videolan_vlc_LibVLC_getMediaListItems(
+void Java_org_videolan_libvlc_LibVLC_getMediaListItems(
                 JNIEnv *env, jobject thiz, jobject arrayList) {
     jclass arrayClass = (*env)->FindClass(env, "java/util/ArrayList");
     jmethodID methodID = (*env)->GetMethodID(env, arrayClass, "add", "(Ljava/lang/Object;)Z");
@@ -756,7 +752,7 @@ void Java_org_videolan_vlc_LibVLC_getMediaListItems(
     libvlc_media_list_unlock( p_mlist );
 }
 
-jfloat Java_org_videolan_vlc_LibVLC_getRate(JNIEnv *env, jobject thiz) {
+jfloat Java_org_videolan_libvlc_LibVLC_getRate(JNIEnv *env, jobject thiz) {
     libvlc_media_player_t* mp = getMediaPlayer(env, thiz);
     if(mp)
         return libvlc_media_player_get_rate(mp);
@@ -764,13 +760,13 @@ jfloat Java_org_videolan_vlc_LibVLC_getRate(JNIEnv *env, jobject thiz) {
         return 1.00;
 }
 
-void Java_org_videolan_vlc_LibVLC_setRate(JNIEnv *env, jobject thiz, jfloat rate) {
+void Java_org_videolan_libvlc_LibVLC_setRate(JNIEnv *env, jobject thiz, jfloat rate) {
     libvlc_media_player_t* mp = getMediaPlayer(env, thiz);
     if(mp)
         libvlc_media_player_set_rate(mp, rate);
 }
 
-jboolean Java_org_videolan_vlc_LibVLC_hasVideoTrack(JNIEnv *env, jobject thiz,
+jboolean Java_org_videolan_libvlc_LibVLC_hasVideoTrack(JNIEnv *env, jobject thiz,
                                                     jlong i_instance, jstring fileLocation)
 {
     /* Create a new item and assign it to the media player. */
@@ -838,10 +834,10 @@ jboolean Java_org_videolan_vlc_LibVLC_hasVideoTrack(JNIEnv *env, jobject thiz,
 jobjectArray read_track_info_internal(JNIEnv *env, jobject thiz, libvlc_media_t* p_m)
 {
     /* get java class */
-    jclass cls = (*env)->FindClass( env, "org/videolan/vlc/TrackInfo" );
+    jclass cls = (*env)->FindClass( env, "org/videolan/libvlc/TrackInfo" );
     if ( !cls )
     {
-        LOGE("Failed to load class (org/videolan/vlc/TrackInfo)" );
+        LOGE("Failed to load class (org/videolan/libvlc/TrackInfo)" );
         return NULL;
     }
 
@@ -849,7 +845,7 @@ jobjectArray read_track_info_internal(JNIEnv *env, jobject thiz, libvlc_media_t*
     jmethodID clsCtor = (*env)->GetMethodID( env, cls, "<init>", "()V" );
     if ( !clsCtor )
     {
-        LOGE("Failed to find class constructor (org/videolan/vlc/TrackInfo)" );
+        LOGE("Failed to find class constructor (org/videolan/libvlc/TrackInfo)" );
         return NULL;
     }
 
@@ -906,7 +902,7 @@ jobjectArray read_track_info_internal(JNIEnv *env, jobject thiz, libvlc_media_t*
 }
 
 
-jobjectArray Java_org_videolan_vlc_LibVLC_readTracksInfo(JNIEnv *env, jobject thiz,
+jobjectArray Java_org_videolan_libvlc_LibVLC_readTracksInfo(JNIEnv *env, jobject thiz,
                                                          jlong instance, jstring mrl)
 {
     /* Create a new item and assign it to the media player. */
@@ -924,7 +920,7 @@ jobjectArray Java_org_videolan_vlc_LibVLC_readTracksInfo(JNIEnv *env, jobject th
 }
 
 
-jobjectArray Java_org_videolan_vlc_LibVLC_readTracksInfoPosition(JNIEnv *env, jobject thiz,
+jobjectArray Java_org_videolan_libvlc_LibVLC_readTracksInfoPosition(JNIEnv *env, jobject thiz,
                                                          jint position)
 {
     libvlc_media_list_t* p_mlist = getMediaList(env, thiz);
@@ -936,7 +932,7 @@ jobjectArray Java_org_videolan_vlc_LibVLC_readTracksInfoPosition(JNIEnv *env, jo
         return read_track_info_internal(env, thiz, p_m);
 }
 
-jlong Java_org_videolan_vlc_LibVLC_getLengthFromLocation(JNIEnv *env, jobject thiz,
+jlong Java_org_videolan_libvlc_LibVLC_getLengthFromLocation(JNIEnv *env, jobject thiz,
                                                      jlong i_instance, jstring fileLocation)
 {
     jlong length = 0;
@@ -982,12 +978,12 @@ end:
     return length;
 }
 
-jboolean Java_org_videolan_vlc_LibVLC_hasMediaPlayer(JNIEnv *env, jobject thiz)
+jboolean Java_org_videolan_libvlc_LibVLC_hasMediaPlayer(JNIEnv *env, jobject thiz)
 {
     return !!getMediaListPlayer(env, thiz);
 }
 
-jboolean Java_org_videolan_vlc_LibVLC_isPlaying(JNIEnv *env, jobject thiz)
+jboolean Java_org_videolan_libvlc_LibVLC_isPlaying(JNIEnv *env, jobject thiz)
 {
     libvlc_media_list_player_t *mp = getMediaListPlayer(env, thiz);
     if (mp)
@@ -996,7 +992,7 @@ jboolean Java_org_videolan_vlc_LibVLC_isPlaying(JNIEnv *env, jobject thiz)
         return 0;
 }
 
-jboolean Java_org_videolan_vlc_LibVLC_isSeekable(JNIEnv *env, jobject thiz)
+jboolean Java_org_videolan_libvlc_LibVLC_isSeekable(JNIEnv *env, jobject thiz)
 {
     libvlc_media_player_t *mp = getMediaPlayer(env, thiz);
     if (mp)
@@ -1004,42 +1000,42 @@ jboolean Java_org_videolan_vlc_LibVLC_isSeekable(JNIEnv *env, jobject thiz)
     return 0;
 }
 
-void Java_org_videolan_vlc_LibVLC_play(JNIEnv *env, jobject thiz)
+void Java_org_videolan_libvlc_LibVLC_play(JNIEnv *env, jobject thiz)
 {
     libvlc_media_list_player_t *mp = getMediaListPlayer(env, thiz);
     if (mp)
         libvlc_media_list_player_play(mp);
 }
 
-void Java_org_videolan_vlc_LibVLC_pause(JNIEnv *env, jobject thiz)
+void Java_org_videolan_libvlc_LibVLC_pause(JNIEnv *env, jobject thiz)
 {
     libvlc_media_list_player_t *mp = getMediaListPlayer(env, thiz);
     if (mp)
         libvlc_media_list_player_pause(mp);
 }
 
-void Java_org_videolan_vlc_LibVLC_stop(JNIEnv *env, jobject thiz)
+void Java_org_videolan_libvlc_LibVLC_stop(JNIEnv *env, jobject thiz)
 {
     libvlc_media_list_player_t *mp = getMediaListPlayer(env, thiz);
     if (mp)
         libvlc_media_list_player_stop(mp);
 }
 
-void Java_org_videolan_vlc_LibVLC_previous(JNIEnv *env, jobject thiz)
+void Java_org_videolan_libvlc_LibVLC_previous(JNIEnv *env, jobject thiz)
 {
     libvlc_media_list_player_t *mp = getMediaListPlayer(env, thiz);
     if (mp)
         libvlc_media_list_player_previous(mp);
 }
 
-void Java_org_videolan_vlc_LibVLC_next(JNIEnv *env, jobject thiz)
+void Java_org_videolan_libvlc_LibVLC_next(JNIEnv *env, jobject thiz)
 {
     libvlc_media_list_player_t *mp = getMediaListPlayer(env, thiz);
     if (mp)
         libvlc_media_list_player_next(mp);
 }
 
-jint Java_org_videolan_vlc_LibVLC_getVolume(JNIEnv *env, jobject thiz)
+jint Java_org_videolan_libvlc_LibVLC_getVolume(JNIEnv *env, jobject thiz)
 {
     libvlc_media_player_t *mp = getMediaPlayer(env, thiz);
     if (mp)
@@ -1047,7 +1043,7 @@ jint Java_org_videolan_vlc_LibVLC_getVolume(JNIEnv *env, jobject thiz)
     return -1;
 }
 
-jint Java_org_videolan_vlc_LibVLC_setVolume(JNIEnv *env, jobject thiz, jint volume)
+jint Java_org_videolan_libvlc_LibVLC_setVolume(JNIEnv *env, jobject thiz, jint volume)
 {
     libvlc_media_player_t *mp = getMediaPlayer(env, thiz);
     if (mp)
@@ -1056,7 +1052,7 @@ jint Java_org_videolan_vlc_LibVLC_setVolume(JNIEnv *env, jobject thiz, jint volu
     return -1;
 }
 
-jlong Java_org_videolan_vlc_LibVLC_getTime(JNIEnv *env, jobject thiz)
+jlong Java_org_videolan_libvlc_LibVLC_getTime(JNIEnv *env, jobject thiz)
 {
     libvlc_media_player_t *mp = getMediaPlayer(env, thiz);
     if (mp)
@@ -1064,14 +1060,14 @@ jlong Java_org_videolan_vlc_LibVLC_getTime(JNIEnv *env, jobject thiz)
     return -1;
 }
 
-void Java_org_videolan_vlc_LibVLC_setTime(JNIEnv *env, jobject thiz, jlong time)
+void Java_org_videolan_libvlc_LibVLC_setTime(JNIEnv *env, jobject thiz, jlong time)
 {
     libvlc_media_player_t *mp = getMediaPlayer(env, thiz);
     if (mp)
         libvlc_media_player_set_time(mp, time);
 }
 
-jfloat Java_org_videolan_vlc_LibVLC_getPosition(JNIEnv *env, jobject thiz)
+jfloat Java_org_videolan_libvlc_LibVLC_getPosition(JNIEnv *env, jobject thiz)
 {
     libvlc_media_player_t *mp = getMediaPlayer(env, thiz);
     if (mp)
@@ -1079,14 +1075,14 @@ jfloat Java_org_videolan_vlc_LibVLC_getPosition(JNIEnv *env, jobject thiz)
     return -1;
 }
 
-void Java_org_videolan_vlc_LibVLC_setPosition(JNIEnv *env, jobject thiz, jfloat pos)
+void Java_org_videolan_libvlc_LibVLC_setPosition(JNIEnv *env, jobject thiz, jfloat pos)
 {
     libvlc_media_player_t *mp = getMediaPlayer(env, thiz);
     if (mp)
         libvlc_media_player_set_position(mp, pos);
 }
 
-jlong Java_org_videolan_vlc_LibVLC_getLength(JNIEnv *env, jobject thiz)
+jlong Java_org_videolan_libvlc_LibVLC_getLength(JNIEnv *env, jobject thiz)
 {
     libvlc_media_player_t *mp = getMediaPlayer(env, thiz);
     if (mp)
@@ -1094,22 +1090,22 @@ jlong Java_org_videolan_vlc_LibVLC_getLength(JNIEnv *env, jobject thiz)
     return -1;
 }
 
-jstring Java_org_videolan_vlc_LibVLC_version(JNIEnv* env, jobject thiz)
+jstring Java_org_videolan_libvlc_LibVLC_version(JNIEnv* env, jobject thiz)
 {
     return (*env)->NewStringUTF(env, libvlc_get_version());
 }
 
-jstring Java_org_videolan_vlc_LibVLC_compiler(JNIEnv* env, jobject thiz)
+jstring Java_org_videolan_libvlc_LibVLC_compiler(JNIEnv* env, jobject thiz)
 {
     return (*env)->NewStringUTF(env, libvlc_get_compiler());
 }
 
-jstring Java_org_videolan_vlc_LibVLC_changeset(JNIEnv* env, jobject thiz)
+jstring Java_org_videolan_libvlc_LibVLC_changeset(JNIEnv* env, jobject thiz)
 {
     return (*env)->NewStringUTF(env, libvlc_get_changeset());
 }
 
-jint Java_org_videolan_vlc_LibVLC_getAudioTracksCount(JNIEnv *env, jobject thiz)
+jint Java_org_videolan_libvlc_LibVLC_getAudioTracksCount(JNIEnv *env, jobject thiz)
 {
     libvlc_media_player_t *mp = getMediaPlayer(env, thiz);
     if (mp)
@@ -1117,7 +1113,7 @@ jint Java_org_videolan_vlc_LibVLC_getAudioTracksCount(JNIEnv *env, jobject thiz)
     return -1;
 }
 
-jobject Java_org_videolan_vlc_LibVLC_getAudioTrackDescription(JNIEnv *env, jobject thiz)
+jobject Java_org_videolan_libvlc_LibVLC_getAudioTrackDescription(JNIEnv *env, jobject thiz)
 {
     libvlc_media_player_t *mp = getMediaPlayer(env, thiz);
     if (!mp)
@@ -1160,7 +1156,7 @@ jobject Java_org_videolan_vlc_LibVLC_getAudioTrackDescription(JNIEnv *env, jobje
     return audioTrackMap;
 }
 
-jint Java_org_videolan_vlc_LibVLC_getAudioTrack(JNIEnv *env, jobject thiz)
+jint Java_org_videolan_libvlc_LibVLC_getAudioTrack(JNIEnv *env, jobject thiz)
 {
     libvlc_media_player_t *mp = getMediaPlayer(env, thiz);
     if (mp)
@@ -1168,7 +1164,7 @@ jint Java_org_videolan_vlc_LibVLC_getAudioTrack(JNIEnv *env, jobject thiz)
     return -1;
 }
 
-jint Java_org_videolan_vlc_LibVLC_setAudioTrack(JNIEnv *env, jobject thiz, jint index)
+jint Java_org_videolan_libvlc_LibVLC_setAudioTrack(JNIEnv *env, jobject thiz, jint index)
 {
     libvlc_media_player_t *mp = getMediaPlayer(env, thiz);
     if (mp)
@@ -1176,7 +1172,7 @@ jint Java_org_videolan_vlc_LibVLC_setAudioTrack(JNIEnv *env, jobject thiz, jint
     return -1;
 }
 
-jint Java_org_videolan_vlc_LibVLC_getVideoTracksCount(JNIEnv *env, jobject thiz)
+jint Java_org_videolan_libvlc_LibVLC_getVideoTracksCount(JNIEnv *env, jobject thiz)
 {
     libvlc_media_player_t *mp = getMediaPlayer(env, thiz);
     if (mp)
@@ -1184,7 +1180,7 @@ jint Java_org_videolan_vlc_LibVLC_getVideoTracksCount(JNIEnv *env, jobject thiz)
     return -1;
 }
 
-jobject Java_org_videolan_vlc_LibVLC_getSpuTrackDescription(JNIEnv *env, jobject thiz)
+jobject Java_org_videolan_libvlc_LibVLC_getSpuTrackDescription(JNIEnv *env, jobject thiz)
 {
     libvlc_media_player_t *mp = getMediaPlayer(env, thiz);
     if (!mp)
@@ -1225,7 +1221,7 @@ jobject Java_org_videolan_vlc_LibVLC_getSpuTrackDescription(JNIEnv *env, jobject
     return spuTrackMap;
 }
 
-jint Java_org_videolan_vlc_LibVLC_getSpuTracksCount(JNIEnv *env, jobject thiz)
+jint Java_org_videolan_libvlc_LibVLC_getSpuTracksCount(JNIEnv *env, jobject thiz)
 {
     libvlc_media_player_t *mp = getMediaPlayer(env, thiz);
     if (mp)
@@ -1233,7 +1229,7 @@ jint Java_org_videolan_vlc_LibVLC_getSpuTracksCount(JNIEnv *env, jobject thiz)
     return -1;
 }
 
-jint Java_org_videolan_vlc_LibVLC_getSpuTrack(JNIEnv *env, jobject thiz)
+jint Java_org_videolan_libvlc_LibVLC_getSpuTrack(JNIEnv *env, jobject thiz)
 {
     libvlc_media_player_t *mp = getMediaPlayer(env, thiz);
     if (mp)
@@ -1241,7 +1237,7 @@ jint Java_org_videolan_vlc_LibVLC_getSpuTrack(JNIEnv *env, jobject thiz)
     return -1;
 }
 
-jint Java_org_videolan_vlc_LibVLC_setSpuTrack(JNIEnv *env, jobject thiz, jint index)
+jint Java_org_videolan_libvlc_LibVLC_setSpuTrack(JNIEnv *env, jobject thiz, jint index)
 {
     libvlc_media_player_t *mp = getMediaPlayer(env, thiz);
     if (mp)
@@ -1249,7 +1245,7 @@ jint Java_org_videolan_vlc_LibVLC_setSpuTrack(JNIEnv *env, jobject thiz, jint in
     return -1;
 }
 
-void Java_org_videolan_vlc_LibVLC_nativeReadDirectory(JNIEnv *env, jobject thiz, jstring path, jobject arrayList)
+void Java_org_videolan_libvlc_LibVLC_nativeReadDirectory(JNIEnv *env, jobject thiz, jstring path, jobject arrayList)
 {
     jboolean isCopy;
     /* Get C string */
@@ -1281,7 +1277,7 @@ void Java_org_videolan_vlc_LibVLC_nativeReadDirectory(JNIEnv *env, jobject thiz,
     closedir(p_dir);
 }
 
-jboolean Java_org_videolan_vlc_LibVLC_nativeIsPathDirectory(JNIEnv *env, jobject thiz, jstring path)
+jboolean Java_org_videolan_libvlc_LibVLC_nativeIsPathDirectory(JNIEnv *env, jobject thiz, jstring path)
 {
     jboolean isCopy;
     /* Get C string */
