@@ -33,6 +33,9 @@ import java.util.HashMap;
 import java.util.List;
 import java.util.Stack;
 
+import org.videolan.libvlc.EventHandler;
+import org.videolan.libvlc.LibVLC;
+import org.videolan.libvlc.LibVlcException;
 import org.videolan.vlc.gui.MainActivity;
 import org.videolan.vlc.gui.audio.AudioPlayerActivity;
 import org.videolan.vlc.gui.audio.AudioUtil;
@@ -41,6 +44,7 @@ import org.videolan.vlc.interfaces.IAudioService;
 import org.videolan.vlc.interfaces.IAudioServiceCallback;
 
 import android.annotation.TargetApi;
+import android.app.Notification;
 import android.app.PendingIntent;
 import android.app.Service;
 import android.content.BroadcastReceiver;
@@ -55,6 +59,7 @@ import android.media.AudioManager.OnAudioFocusChangeListener;
 import android.media.MediaMetadataRetriever;
 import android.media.RemoteControlClient;
 import android.media.RemoteControlClient.MetadataEditor;
+import android.os.Build;
 import android.os.Handler;
 import android.os.IBinder;
 import android.os.Message;
@@ -64,6 +69,7 @@ import android.preference.PreferenceManager;
 import android.support.v4.app.NotificationCompat;
 import android.telephony.TelephonyManager;
 import android.util.Log;
+import android.widget.RemoteViews;
 
 public class AudioService extends Service {
 
@@ -90,7 +96,7 @@ public class AudioService extends Service {
     private Stack<Media> mPrevious;
     private Media mCurrentMedia;
     private HashMap<IAudioServiceCallback, Integer> mCallback;
-    private EventManager mEventManager;
+    private EventHandler mEventHandler;
     private boolean mShuffling = false;
     private RepeatType mRepeating = RepeatType.None;
     private boolean mDetectHeadset = true;
@@ -123,7 +129,7 @@ public class AudioService extends Service {
 
         // Get libVLC instance
         try {
-            mLibVLC = LibVLC.getInstance();
+            mLibVLC = Util.getLibVlcInstance();
         } catch (LibVlcException e) {
             e.printStackTrace();
         }
@@ -133,7 +139,7 @@ public class AudioService extends Service {
         mCallback = new HashMap<IAudioServiceCallback, Integer>();
         mMediaList = new ArrayList<Media>();
         mPrevious = new Stack<Media>();
-        mEventManager = EventManager.getInstance();
+        mEventHandler = EventHandler.getInstance();
         mRemoteControlClientReceiverComponent = new ComponentName(getPackageName(),
                 RemoteControlClientReceiver.class.getName());
 
@@ -351,7 +357,7 @@ public class AudioService extends Service {
     /**
      * Handle libvlc asynchronous events
      */
-    private final Handler mEventHandler = new AudioServiceEventHandler(this);
+    private final Handler mVlcEventHandler = new AudioServiceEventHandler(this);
 
     private static class AudioServiceEventHandler extends WeakHandler<AudioService> {
         public AudioServiceEventHandler(AudioService fragment) {
@@ -364,14 +370,14 @@ public class AudioService extends Service {
             if(service == null) return;
 
             switch (msg.getData().getInt("event")) {
-                case EventManager.MediaPlayerPlaying:
+                case EventHandler.MediaPlayerPlaying:
                     Log.i(TAG, "MediaPlayerPlaying");
 
                     if (service.mCurrentMedia == null)
                         return;
                     String location = service.mCurrentMedia.getLocation();
                     long length = service.mLibVLC.getLength();
-                    DatabaseManager dbManager = DatabaseManager
+                    MediaDatabase dbManager = MediaDatabase
                             .getInstance(VLCApplication.getAppContext());
                     Media m = dbManager.getMedia(VLCApplication.getAppContext(),
                             location);
@@ -385,7 +391,7 @@ public class AudioService extends Service {
                     if(m != null && m.getLength() == 0 && length > 0) {
                         Log.d(TAG, "Updating audio file length");
                         dbManager.updateMedia(location,
-                                DatabaseManager.mediaColumn.MEDIA_LENGTH, length);
+                                MediaDatabase.mediaColumn.MEDIA_LENGTH, length);
                     }
 
                     service.changeAudioFocus(true);
@@ -393,35 +399,34 @@ public class AudioService extends Service {
                     if (!service.mWakeLock.isHeld())
                         service.mWakeLock.acquire();
                     break;
-                case EventManager.MediaPlayerPaused:
+                case EventHandler.MediaPlayerPaused:
                     Log.i(TAG, "MediaPlayerPaused");
                     service.executeUpdate();
-                    // also hide notification if phone ringing
-                    service.hideNotification();
+                    service.showNotification();
                     service.setRemoteControlClientPlaybackState(RemoteControlClient.PLAYSTATE_PAUSED);
                     if (service.mWakeLock.isHeld())
                         service.mWakeLock.release();
                     break;
-                case EventManager.MediaPlayerStopped:
+                case EventHandler.MediaPlayerStopped:
                     Log.i(TAG, "MediaPlayerStopped");
                     service.executeUpdate();
                     service.setRemoteControlClientPlaybackState(RemoteControlClient.PLAYSTATE_STOPPED);
                     if (service.mWakeLock.isHeld())
                         service.mWakeLock.release();
                     break;
-                case EventManager.MediaPlayerEndReached:
+                case EventHandler.MediaPlayerEndReached:
                     Log.i(TAG, "MediaPlayerEndReached");
                     service.executeUpdate();
                     service.next();
                     if (service.mWakeLock.isHeld())
                         service.mWakeLock.release();
                     break;
-                case EventManager.MediaPlayerVout:
+                case EventHandler.MediaPlayerVout:
                     if(msg.getData().getInt("data") > 0) {
                         service.handleVout();
                     }
                     break;
-                case EventManager.MediaPlayerPositionChanged:
+                case EventHandler.MediaPlayerPositionChanged:
                     float pos = msg.getData().getFloat("data");
                     service.updateWidgetPosition(service, pos);
                     break;
@@ -484,27 +489,76 @@ public class AudioService extends Service {
         }
     };
 
+    @TargetApi(Build.VERSION_CODES.JELLY_BEAN)
     private void showNotification() {
         try {
+            Bitmap cover = AudioUtil.getCover(this, mCurrentMedia, 64);
+            String title = mCurrentMedia.getTitle();
+            String artist = mCurrentMedia.getArtist();
+            String album = mCurrentMedia.getAlbum();
+            Notification notification;
+
             // add notification to status bar
             NotificationCompat.Builder builder = new NotificationCompat.Builder(this)
-            .setSmallIcon(R.drawable.icon)
-            .setLargeIcon(AudioUtil.getCover(this, mCurrentMedia, 64))
-            .setContentTitle(mCurrentMedia.getTitle())
-            .setTicker(mCurrentMedia.getTitle() + " - " + mCurrentMedia.getArtist())
-            .setContentText(Util.isJellyBeanOrLater() ? mCurrentMedia.getArtist() : mCurrentMedia.getSubtitle())
-            .setContentInfo(mCurrentMedia.getAlbum())
-            .setAutoCancel(false)
-            .setOngoing(true);
+                .setSmallIcon(R.drawable.ic_stat_vlc)
+                .setTicker(title + " - " + artist)
+                .setAutoCancel(false)
+                .setOngoing(true);
 
             Intent notificationIntent = new Intent(this, AudioPlayerActivity.class);
             notificationIntent.setAction(Intent.ACTION_MAIN);
             notificationIntent.addCategory(Intent.CATEGORY_LAUNCHER);
             notificationIntent.putExtra(START_FROM_NOTIFICATION, true);
-            PendingIntent pendingIntent = PendingIntent.getActivity(this, 0, notificationIntent, 0);
+            PendingIntent pendingIntent = PendingIntent.getActivity(this, 0, notificationIntent, PendingIntent.FLAG_UPDATE_CURRENT);
 
-            builder.setContentIntent(pendingIntent);
-            startForeground(3, builder.build());
+            if (Util.isJellyBeanOrLater()) {
+                Intent iBackward = new Intent(ACTION_REMOTE_BACKWARD);
+                Intent iPlay = new Intent(ACTION_REMOTE_PLAYPAUSE);
+                Intent iForward = new Intent(ACTION_REMOTE_FORWARD);
+                Intent iStop = new Intent(ACTION_REMOTE_STOP);
+                PendingIntent piBackward = PendingIntent.getBroadcast(this, 0, iBackward, PendingIntent.FLAG_UPDATE_CURRENT);
+                PendingIntent piPlay = PendingIntent.getBroadcast(this, 0, iPlay, PendingIntent.FLAG_UPDATE_CURRENT);
+                PendingIntent piForward = PendingIntent.getBroadcast(this, 0, iForward, PendingIntent.FLAG_UPDATE_CURRENT);
+                PendingIntent piStop = PendingIntent.getBroadcast(this, 0, iStop, PendingIntent.FLAG_UPDATE_CURRENT);
+
+                RemoteViews view = new RemoteViews(getPackageName(), R.layout.notification);
+                if (cover != null)
+                    view.setImageViewBitmap(R.id.cover, cover);
+                view.setTextViewText(R.id.songName, title);
+                view.setTextViewText(R.id.artist, artist);
+                view.setImageViewResource(R.id.play_pause, mLibVLC.isPlaying() ? R.drawable.ic_pause : R.drawable.ic_play);
+                view.setOnClickPendingIntent(R.id.play_pause, piPlay);
+                view.setOnClickPendingIntent(R.id.forward, piForward);
+                view.setOnClickPendingIntent(R.id.stop, piStop);
+                view.setOnClickPendingIntent(R.id.content, pendingIntent);
+
+                RemoteViews view_expanded = new RemoteViews(getPackageName(), R.layout.notification_expanded);
+                if (cover != null)
+                    view_expanded.setImageViewBitmap(R.id.cover, cover);
+                view_expanded.setTextViewText(R.id.songName, title);
+                view_expanded.setTextViewText(R.id.artist, artist);
+                view_expanded.setTextViewText(R.id.album, album);
+                view_expanded.setImageViewResource(R.id.play_pause, mLibVLC.isPlaying() ? R.drawable.ic_pause : R.drawable.ic_play);
+                view_expanded.setOnClickPendingIntent(R.id.backward, piBackward);
+                view_expanded.setOnClickPendingIntent(R.id.play_pause, piPlay);
+                view_expanded.setOnClickPendingIntent(R.id.forward, piForward);
+                view_expanded.setOnClickPendingIntent(R.id.stop, piStop);
+                view_expanded.setOnClickPendingIntent(R.id.content, pendingIntent);
+
+                notification = builder.build();
+                notification.contentView = view;
+                notification.bigContentView = view_expanded;
+            }
+            else {
+                builder.setLargeIcon(cover)
+                       .setContentTitle(title)
+                       .setContentText(Util.isJellyBeanOrLater() ? artist : mCurrentMedia.getSubtitle())
+                       .setContentInfo(album)
+                       .setContentIntent(pendingIntent);
+                notification = builder.build();
+            }
+
+            startForeground(3, notification);
         }
         catch (NoSuchMethodError e){
             // Compat library is wrong on 3.2
@@ -536,7 +590,7 @@ public class AudioService extends Service {
 
     private void stop() {
         mLibVLC.stop();
-        mEventManager.removeHandler(mEventHandler);
+        mEventHandler.removeHandler(mVlcEventHandler);
         setRemoteControlClientPlaybackState(RemoteControlClient.PLAYSTATE_STOPPED);
         mCurrentMedia = null;
         mMediaList.clear();
@@ -754,7 +808,7 @@ public class AudioService extends Service {
             mLibVLCPlaylistActive = libvlcBacked;
 
             Log.v(TAG, "Loading position " + ((Integer)position).toString() + " in " + mediaPathList.toString());
-            mEventManager.addHandler(mEventHandler);
+            mEventHandler.addHandler(mVlcEventHandler);
 
             mMediaList.clear();
             mPrevious.clear();
@@ -763,7 +817,7 @@ public class AudioService extends Service {
                 for(int i = 0; i < mediaPathList.size(); i++)
                     mMediaList.add(new Media(mediaPathList.get(i), i));
             } else {
-                DatabaseManager db = DatabaseManager.getInstance(AudioService.this);
+                MediaDatabase db = MediaDatabase.getInstance(AudioService.this);
                 for (int i = 0; i < mediaPathList.size(); i++) {
                     String path = mediaPathList.get(i);
                     Media media = db.getMedia(AudioService.this, path);
@@ -801,7 +855,7 @@ public class AudioService extends Service {
 
             if(!mLibVLC.isPlaying())
                 return;
-            mEventManager.addHandler(mEventHandler);
+            mEventHandler.addHandler(mVlcEventHandler);
             mMediaList.clear();
             mPrevious.clear();
             // Prevent re-parsing the media, which would mean losing the connection
@@ -839,7 +893,7 @@ public class AudioService extends Service {
             if(mLibVLCPlaylistActive) {
                 return;
             }
-            DatabaseManager db = DatabaseManager.getInstance(AudioService.this);
+            MediaDatabase db = MediaDatabase.getInstance(AudioService.this);
             for (int i = 0; i < mediaPathList.size(); i++) {
                 String path = mediaPathList.get(i);
                 Media media = db.getMedia(AudioService.this, path);
