@@ -21,7 +21,6 @@
 package org.videolan.vlc;
 
 import java.io.BufferedReader;
-import java.io.ByteArrayInputStream;
 import java.io.File;
 import java.io.FileNotFoundException;
 import java.io.FileReader;
@@ -34,9 +33,11 @@ import java.util.ArrayList;
 import java.util.Arrays;
 import java.util.HashSet;
 import java.util.Locale;
-import java.util.Properties;
 import java.util.StringTokenizer;
 
+import org.videolan.libvlc.LibVLC;
+import org.videolan.libvlc.LibVlcException;
+
 import android.content.Context;
 import android.content.SharedPreferences;
 import android.graphics.Bitmap;
@@ -65,6 +66,39 @@ public class Util {
         hasNavBar = isICSOrLater() && !devicesWithoutNavBar.contains(android.os.Build.MODEL);
     }
 
+    public static LibVLC getLibVlcInstance() throws LibVlcException {
+        LibVLC instance = LibVLC.getExistingInstance();
+        if (instance == null) {
+            instance = LibVLC.getInstance();
+            Context context = VLCApplication.getAppContext();
+            SharedPreferences pref = PreferenceManager.getDefaultSharedPreferences(context);
+            updateLibVlcSettings(pref);
+            instance.init(context);
+        }
+        return instance;
+    }
+
+    public static void updateLibVlcSettings(SharedPreferences pref) {
+        LibVLC instance = LibVLC.getExistingInstance();
+        if (instance == null)
+            return;
+
+        instance.setIomx(pref.getBoolean("enable_iomx", false));
+        instance.setSubtitlesEncoding(pref.getString("subtitles_text_encoding", ""));
+        instance.setTimeStretching(pref.getBoolean("enable_time_stretching_audio", false));
+        instance.setChroma(pref.getString("chroma_format", ""));
+        instance.setVerboseMode(pref.getBoolean("enable_verbose_mode", true));
+
+        int aout;
+        try {
+            aout = Integer.parseInt(pref.getString("aout", "-1"));
+        }
+        catch (NumberFormatException nfe) {
+            aout = -1;
+        }
+        instance.setAout(aout);
+    }
+
     /** Print an on-screen message to alert the user */
     public static void toaster(Context context, int stringId, int duration) {
         Toast.makeText(context, stringId, duration).show();
@@ -82,13 +116,6 @@ public class Util {
         return URItoFile(URI).getName();
     }
 
-    public static String PathToURI(String path) {
-        if(path == null) {
-            throw new NullPointerException("Cannot convert null path!");
-        }
-        return LibVLC.nativeToURI(path);
-    }
-
     public static String stripTrailingSlash(String s) {
         if( s.endsWith("/") && s.length() > 1 )
             return s.substring(0, s.length() - 1);
@@ -263,132 +290,6 @@ public class Util {
                     (android.os.Build.VERSION.SDK_INT <= android.os.Build.VERSION_CODES.JELLY_BEAN)));
     }
 
-    private static String errorMsg = null;
-    private static boolean isCompatible = false;
-    public static String getErrorMsg() {
-        return errorMsg;
-    }
-    public static boolean hasCompatibleCPU()
-    {
-        // If already checked return cached result
-        if(errorMsg != null) return isCompatible;
-
-        Properties properties = new Properties();
-        try {
-            properties.load(new ByteArrayInputStream(Util.readAsset("env.txt", "").getBytes("UTF-8")));
-        } catch (IOException e) {
-            // Shouldn't happen if done correctly
-            e.printStackTrace();
-            errorMsg = "IOException whilst reading compile flags";
-            isCompatible = false;
-            return false;
-        }
-
-        String CPU_ABI = android.os.Build.CPU_ABI;
-        String CPU_ABI2 = "none";
-        if(android.os.Build.VERSION.SDK_INT >= 8) { // CPU_ABI2 since 2.2
-            try {
-                CPU_ABI2 = (String)android.os.Build.class.getDeclaredField("CPU_ABI2").get(null);
-            } catch (Exception e) { }
-        }
-
-        String ANDROID_ABI = properties.getProperty("ANDROID_ABI");
-        boolean NO_FPU = properties.getProperty("NO_FPU","0").equals("1");
-        boolean NO_ARMV6 = properties.getProperty("NO_ARMV6","0").equals("1");
-        boolean hasNeon = false, hasFpu = false, hasArmV6 = false,
-                hasArmV7 = false, hasMips = false;
-        boolean hasX86 = false;
-
-        if(CPU_ABI.equals("x86")) {
-            hasX86 = true;
-        } else if(CPU_ABI.equals("armeabi-v7a") ||
-                  CPU_ABI2.equals("armeabi-v7a")) {
-            hasArmV7 = true;
-            hasArmV6 = true; /* Armv7 is backwards compatible to < v6 */
-        } else if(CPU_ABI.equals("armeabi") ||
-                  CPU_ABI2.equals("armeabi")) {
-            hasArmV6 = true;
-        }
-
-        try {
-            FileReader fileReader = new FileReader("/proc/cpuinfo");
-            BufferedReader br = new BufferedReader(fileReader);
-            String line;
-            while((line = br.readLine()) != null) {
-                if(!hasArmV7 && line.contains("ARMv7")) {
-                    hasArmV7 = true;
-                    hasArmV6 = true; /* Armv7 is backwards compatible to < v6 */
-                }
-                if(!hasArmV7 && !hasArmV6 && line.contains("ARMv6"))
-                    hasArmV6 = true;
-                // "clflush size" is a x86-specific cpuinfo tag.
-                // (see kernel sources arch/x86/kernel/cpu/proc.c)
-                if(line.contains("clflush size"))
-                    hasX86 = true;
-                // "microsecond timers" is specific to MIPS.
-                // see arch/mips/kernel/proc.c
-                if(line.contains("microsecond timers"))
-                    hasMips = true;
-                if(!hasNeon && line.contains("neon"))
-                    hasNeon = true;
-                if(!hasFpu && line.contains("vfp"))
-                    hasFpu = true;
-            }
-            fileReader.close();
-        } catch(IOException ex){
-            ex.printStackTrace();
-            errorMsg = "IOException whilst reading cpuinfo flags";
-            isCompatible = false;
-            return false;
-        }
-
-        // Enforce proper architecture to prevent problems
-        if(ANDROID_ABI.equals("x86") && !hasX86) {
-            errorMsg = "x86 build on non-x86 device";
-            isCompatible = false;
-            return false;
-        } else if(hasX86 && ANDROID_ABI.contains("armeabi")) {
-            errorMsg = "ARM build on x86 device";
-            isCompatible = false;
-            return false;
-        }
-
-        if(ANDROID_ABI.equals("mips") && !hasMips) {
-            errorMsg = "MIPS build on non-MIPS device";
-            isCompatible = false;
-            return false;
-        } else if(hasMips && ANDROID_ABI.contains("armeabi")) {
-            errorMsg = "ARM build on MIPS device";
-            isCompatible = false;
-            return false;
-        }
-
-        if(ANDROID_ABI.equals("armeabi-v7a") && !hasArmV7) {
-            errorMsg = "ARMv7 build on non-ARMv7 device";
-            isCompatible = false;
-            return false;
-        }
-        if(ANDROID_ABI.equals("armeabi")) {
-            if(!NO_ARMV6 && !hasArmV6) {
-                errorMsg = "ARMv6 build on non-ARMv6 device";
-                isCompatible = false;
-                return false;
-            } else if(!NO_FPU && !hasFpu) {
-                errorMsg = "FPU-enabled build on non-FPU device";
-                isCompatible = false;
-                return false;
-            }
-        }
-        if(ANDROID_ABI.equals("armeabi") || ANDROID_ABI.equals("armeabi-v7a")) {
-            if(!hasNeon) {
-                errorMsg = "NEON build on non-NEON device";
-            }
-        }
-        errorMsg = null;
-        isCompatible = true;
-        return true;
-    }
-
     public static boolean isPhone(){
         TelephonyManager manager = (TelephonyManager)VLCApplication.getAppContext().getSystemService(Context.TELEPHONY_SERVICE);
         if(manager.getPhoneType() == TelephonyManager.PHONE_TYPE_NONE){
