@@ -26,17 +26,18 @@ import java.lang.reflect.Method;
 import java.net.URLDecoder;
 import java.util.Map;
 
+import org.videolan.libvlc.EventHandler;
+import org.videolan.libvlc.IVideoPlayer;
+import org.videolan.libvlc.LibVLC;
+import org.videolan.libvlc.LibVlcException;
 import org.videolan.vlc.AudioServiceController;
-import org.videolan.vlc.DatabaseManager;
-import org.videolan.vlc.EventManager;
-import org.videolan.vlc.LibVLC;
-import org.videolan.vlc.LibVlcException;
 import org.videolan.vlc.Media;
+import org.videolan.vlc.MediaDatabase;
 import org.videolan.vlc.R;
 import org.videolan.vlc.Util;
 import org.videolan.vlc.VLCApplication;
 import org.videolan.vlc.WeakHandler;
-import org.videolan.vlc.gui.AdvFuncDialog;
+import org.videolan.vlc.gui.CommonDialogs;
 import org.videolan.vlc.gui.PreferencesActivity;
 import org.videolan.vlc.gui.audio.AudioPlayerActivity;
 import org.videolan.vlc.interfaces.IPlayerControl;
@@ -89,7 +90,7 @@ import android.widget.SeekBar;
 import android.widget.SeekBar.OnSeekBarChangeListener;
 import android.widget.TextView;
 
-public class VideoPlayerActivity extends Activity {
+public class VideoPlayerActivity extends Activity implements IVideoPlayer {
 
     public final static String TAG = "VLC/VideoPlayerActivity";
 
@@ -175,9 +176,6 @@ public class VideoPlayerActivity extends Activity {
     private Map<Integer,String> mAudioTracksList;
     private Map<Integer,String> mSubtitleTracksList;
 
-    // Advance Function
-    private AdvFuncDialog mAdvFuncDialog;
-
     @Override
     @TargetApi(11)
     protected void onCreate(Bundle savedInstanceState) {
@@ -299,13 +297,13 @@ public class VideoPlayerActivity extends Activity {
         registerReceiver(mReceiver, filter);
 
         try {
-            mLibVLC = LibVLC.getInstance();
+            mLibVLC = Util.getLibVlcInstance();
         } catch (LibVlcException e) {
             Log.d(TAG, "LibVLC initialisation failed");
             return;
         }
 
-        EventManager em = EventManager.getInstance();
+        EventHandler em = EventHandler.getInstance();
         em.addHandler(eventHandler);
 
         this.setVolumeControlStream(AudioManager.STREAM_MUSIC);
@@ -366,11 +364,11 @@ public class VideoPlayerActivity extends Activity {
         if (time >= 0) {
             SharedPreferences preferences = getSharedPreferences(PreferencesActivity.NAME, MODE_PRIVATE);
             SharedPreferences.Editor editor = preferences.edit();
-            if(DatabaseManager.getInstance(this).mediaItemExists(mLocation)) {
+            if(MediaDatabase.getInstance(this).mediaItemExists(mLocation)) {
                 editor.putString(PreferencesActivity.LAST_MEDIA, mLocation);
-                DatabaseManager.getInstance(this).updateMedia(
+                MediaDatabase.getInstance(this).updateMedia(
                         mLocation,
-                        DatabaseManager.mediaColumn.MEDIA_TIME,
+                        MediaDatabase.mediaColumn.MEDIA_TIME,
                         time);
             } else {
                 // Video file not in media library, store time just for onResume()
@@ -385,8 +383,6 @@ public class VideoPlayerActivity extends Activity {
     @Override
     protected void onStop() {
         super.onStop();
-        if (mAdvFuncDialog != null)
-            mAdvFuncDialog.destroyAdvFuncDialog();
     }
 
     @Override
@@ -397,7 +393,7 @@ public class VideoPlayerActivity extends Activity {
             mLibVLC.stop();
         }
 
-        EventManager em = EventManager.getInstance();
+        EventHandler em = EventHandler.getInstance();
         em.removeHandler(eventHandler);
 
         mAudioManager = null;
@@ -422,7 +418,7 @@ public class VideoPlayerActivity extends Activity {
                 if (mLibVLC != null && mLibVLC.isPlaying()) {
                     KeyguardManager km = (KeyguardManager)getSystemService(KEYGUARD_SERVICE);
                     if (km.inKeyguardRestrictedInputMode())
-            mLibVLC.pause();
+                        mLibVLC.pause();
                 }
             }}, 500);
 
@@ -493,6 +489,7 @@ public class VideoPlayerActivity extends Activity {
         super.onConfigurationChanged(newConfig);
     }
 
+    @Override
     public void setSurfaceSize(int width, int height, int sar_num, int sar_den) {
         if (width * height == 0)
             return;
@@ -602,26 +599,30 @@ public class VideoPlayerActivity extends Activity {
             if(activity == null) return;
 
             switch (msg.getData().getInt("event")) {
-                case EventManager.MediaPlayerPlaying:
+                case EventHandler.MediaPlayerPlaying:
                     Log.i(TAG, "MediaPlayerPlaying");
                     activity.setESTracks();
                     break;
-                case EventManager.MediaPlayerPaused:
+                case EventHandler.MediaPlayerPaused:
                     Log.i(TAG, "MediaPlayerPaused");
                     break;
-                case EventManager.MediaPlayerStopped:
+                case EventHandler.MediaPlayerStopped:
                     Log.i(TAG, "MediaPlayerStopped");
                     break;
-                case EventManager.MediaPlayerEndReached:
+                case EventHandler.MediaPlayerEndReached:
                     Log.i(TAG, "MediaPlayerEndReached");
                     activity.endReached();
                     break;
-                case EventManager.MediaPlayerVout:
+                case EventHandler.MediaPlayerVout:
                     activity.handleVout(msg);
                     break;
-                case EventManager.MediaPlayerPositionChanged:
+                case EventHandler.MediaPlayerPositionChanged:
                     //don't spam the logs
                     break;
+                case EventHandler.MediaPlayerEncounteredError:
+                    Log.i(TAG, "MediaPlayerEncounteredError");
+                    activity.encounteredError();
+                    break;
                 default:
                     Log.e(TAG, String.format("Event not handled (0x%x)", msg.getData().getInt("event")));
                     break;
@@ -677,6 +678,21 @@ public class VideoPlayerActivity extends Activity {
         finish();
     }
 
+    private void encounteredError() {
+        /* Encountered Error, exit player with a message */
+        AlertDialog dialog = new AlertDialog.Builder(VideoPlayerActivity.this)
+        .setPositiveButton(R.string.ok, new DialogInterface.OnClickListener() {
+            @Override
+            public void onClick(DialogInterface dialog, int id) {
+                finish();
+            }
+        })
+        .setTitle(R.string.encountered_error_title)
+        .setMessage(R.string.encountered_error_message)
+        .create();
+        dialog.show();
+    }
+
     private void handleVout(Message msg) {
         if (msg.getData().getInt("data") == 0 && !mEndReached) {
             /* Video track lost, open in audio mode */
@@ -985,9 +1001,9 @@ public class VideoPlayerActivity extends Activity {
                     }
                     if(trackID < 0) return;
 
-                    DatabaseManager.getInstance(VideoPlayerActivity.this).updateMedia(
+                    MediaDatabase.getInstance(VideoPlayerActivity.this).updateMedia(
                             mLocation,
-                            DatabaseManager.mediaColumn.MEDIA_AUDIOTRACK,
+                            MediaDatabase.mediaColumn.MEDIA_AUDIOTRACK,
                             trackID);
                     mLibVLC.setAudioTrack(trackID);
                     dialog.dismiss();
@@ -1032,9 +1048,9 @@ public class VideoPlayerActivity extends Activity {
                     }
                     if(trackID < -1) return;
 
-                    DatabaseManager.getInstance(VideoPlayerActivity.this).updateMedia(
+                    MediaDatabase.getInstance(VideoPlayerActivity.this).updateMedia(
                             mLocation,
-                            DatabaseManager.mediaColumn.MEDIA_SPUTRACK,
+                            MediaDatabase.mediaColumn.MEDIA_SPUTRACK,
                             trackID);
                     mLibVLC.setSpuTrack(trackID);
                     dialog.dismiss();
@@ -1365,7 +1381,7 @@ public class VideoPlayerActivity extends Activity {
                     Cursor cursor = managedQuery(getIntent().getData(), new String[]{ MediaStore.Video.Media.DATA }, null, null, null);
                     int column_index = cursor.getColumnIndexOrThrow(MediaStore.Video.Media.DATA);
                     if (cursor.moveToFirst())
-                        mLocation = Util.PathToURI(cursor.getString(column_index));
+                        mLocation = LibVLC.PathToURI(cursor.getString(column_index));
                 } else {
                     // other content-based URI (probably file pickers)
                     mLocation = getIntent().getData().getPath();
@@ -1393,7 +1409,7 @@ public class VideoPlayerActivity extends Activity {
 
         if (mLocation != null && mLocation.length() > 0 && !dontParse) {
             // restore last position
-            Media media = DatabaseManager.getInstance(this).getMedia(this, mLocation);
+            Media media = MediaDatabase.getInstance(this).getMedia(this, mLocation);
             if(media != null) {
                 // in media library
                 if(media.getTime() > 0 && !fromStart)
@@ -1466,8 +1482,6 @@ public class VideoPlayerActivity extends Activity {
     }
 
     public void showAdvanceFunction(View v) {
-        if (mAdvFuncDialog == null)
-            mAdvFuncDialog = new AdvFuncDialog(this);
-        mAdvFuncDialog.show();
+        CommonDialogs.advancedOptions(this, v);
     }
 }
